@@ -332,7 +332,7 @@ SensorFace *SensorFaceControllerPrivate::createGui(const QString &qmlPath)
 
 QQuickItem *SensorFaceControllerPrivate::createConfigUi(const QString &file, const QVariantMap &initialProperties)
 {
-    QQmlComponent *component = new QQmlComponent(engine, file, nullptr);
+    QQmlComponent *component = new QQmlComponent(configEngine, file, nullptr);
     // TODO: eventually support async  components? (only useful for qml files from http, we probably don't want that)
     if (component->status() != QQmlComponent::Ready) {
         qCritical() << "Error creating component:";
@@ -343,7 +343,7 @@ QQuickItem *SensorFaceControllerPrivate::createConfigUi(const QString &file, con
         return nullptr;
     }
 
-    QQmlContext *context = new QQmlContext(engine);
+    QQmlContext *context = new QQmlContext(configEngine);
     context->setContextObject(contextObj);
     QObject *guiObject = component->createWithInitialProperties(initialProperties, context);
     QQuickItem *gui = qobject_cast<QQuickItem *>(guiObject);
@@ -356,7 +356,7 @@ QQuickItem *SensorFaceControllerPrivate::createConfigUi(const QString &file, con
     return gui;
 }
 
-SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *engine)
+SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *engine, QQmlEngine *configEngine)
     : QObject(engine)
     , d(std::make_unique<SensorFaceControllerPrivate>())
 {
@@ -367,6 +367,8 @@ SensorFaceController::SensorFaceController(KConfigGroup &config, QQmlEngine *eng
     d->colorsGroup = KConfigGroup(&config, "SensorColors");
     d->labelsGroup = KConfigGroup(&config, "SensorLabels");
     d->engine = engine;
+    // Ensure we don't re-use the Plasma Theme coloring by using separate configEngine, BUG:483689
+    d->configEngine = configEngine;
     d->syncTimer = new QTimer(this);
     d->syncTimer->setSingleShot(true);
     d->syncTimer->setInterval(5000);
